==> jupyter-book-0.10.1.tar.gz: jupyter-book-0.10.1/README.md <==
# <img src="https://raw.githubusercontent.com/executablebooks/jupyter-book/master/docs/images/logo.png" width=40 /> Jupyter Book

[![CircleCI](https://circleci.com/gh/executablebooks/jupyter-book.svg?style=svg)](https://circleci.com/gh/executablebooks/jupyter-book)
[![codecov](https://codecov.io/gh/executablebooks/jupyter-book/branch/master/graph/badge.svg)](https://codecov.io/gh/executablebooks/jupyter-book)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2561065.svg)](https://doi.org/10.5281/zenodo.2561065)
[![PyPI][pypi-badge]][pypi-link]

Jupyter Book is an open-source tool for building publication-quality books and documents from computational material.

Jupyter Book allows users to

* write their content in [markdown files](https://myst-parser.readthedocs.io/en/latest/) or [Jupyter](https://jupyter.org/) notebooks,
* include computational elements (e.g., code cells) in either type,
* include rich syntax such as citations, cross-references, and numbered equations, and
* using a simple command, run the embedded code cells, [cache](https://jupyter-cache.readthedocs.io/en/latest/) the outputs and convert this content into:
    * a web-based interactive book and
    * a publication-quality PDF.

## Governance of this project

Jupyter Book is still developing relatively rapidly, so please be patient if things change
or features iterate and change quickly. Once Jupyter Book hits 1.0, it will slow down
considerably!

## Contribute or improve the book

Notice some inefficient CSS? A typo in the text? Want to add a cool feature so that others
can enjoy the improvements to Jupyter Books? Check out the [Jupyter Book Contributor's
Guide](https://jupyterbook.org/contribute/intro.html). We'd love your help!

## Acknowledgements

Jupyter Book is maintained and primarily developed by
the [Executable Book Project](https://executablebooks.org).

[pypi-badge]: https://img.shields.io/pypi/v/jupyter-book.svg
[pypi-link]: https://pypi.org/project/jupyter-book

==> jupyter-book-0.11.1.tar.gz: jupyter-book-0.11.1/README.md <==
# <img src="https://raw.githubusercontent.com/executablebooks/jupyter-book/master/docs/images/logo-square.png" width=40 /> Jupyter Book

[![CircleCI](https://circleci.com/gh/executablebooks/jupyter-book.svg?style=svg)](https://circleci.com/gh/executablebooks/jupyter-book)
[![codecov](https://codecov.io/gh/executablebooks/jupyter-book/branch/master/graph/badge.svg)](https://codecov.io/gh/executablebooks/jupyter-book)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2561065.svg)](https://doi.org/10.5281/zenodo.2561065)
[![PyPI][pypi-badge]][pypi-link]
[![Conda][conda-badge]][conda-link]

Jupyter Book is an open-source tool for building publication-quality books and documents from computational material.

Jupyter Book allows users to

* write their content in [markdown files](https://myst-parser.readthedocs.io/en/latest/) or [Jupyter](https://jupyter.org/) notebooks,
* include computational elements (e.g., code cells) in either type,
* include rich syntax such as citations, cross-references, and numbered equations, and
* using a simple command, run the embedded code cells, [cache](https://jupyter-cache.readthedocs.io/en/latest/) the outputs and convert this content into:
    * a web-based interactive book and
    * a publication-quality PDF.

## Governance of this project

Jupyter Book is still developing relatively rapidly, so please be patient if things change
or features iterate and change quickly. Once Jupyter Book hits 1.0, it will slow down
considerably!

## Contribute or improve the book

Notice some inefficient CSS? A typo in the text? Want to add a cool feature so that others
can enjoy the improvements to Jupyter Books? Check out the [Jupyter Book Contributor's
Guide](https://jupyterbook.org/contribute/intro.html). We'd love your help!

## Acknowledgements

Jupyter Book is maintained and primarily developed by
the [Executable Book Project](https://executablebooks.org).

[pypi-badge]: https://img.shields.io/pypi/v/jupyter-book.svg
[pypi-link]: https://pypi.org/project/jupyter-book
[conda-badge]: https://anaconda.org/conda-forge/jupyter-book/badges/version.svg
[conda-link]: https://anaconda.org/conda-forge/jupyter-book
